<template>
  <div class="p-4 container">
    <!-- هدر صفحه -->
    <div class="d-flex justify-content-between align-items-center mb-4">
      <div>
        <h5 class="fw-bold text-dark mb-0">{{ t('advertise_story.title') }}</h5>
        <p class="text-muted mb-0">{{ t('advertise_story.subtitle', { title: data.advertiseTitle }) }}</p>
      </div>
      <div>
        <button
          class="btn btn-default btn-sm ms-2"
          @click="data.showModal = true"
        >
          <i class="icon icon-regular-plus ms-0 ms-md-1"></i>
          <span class="d-none d-md-inline-block">{{ t('advertise_story.add_button') }}</span>
        </button>
        <nuxt-link :to="'/account/advertise/show/' + advertiseId" class="btn btn-outline-secondary btn-sm">
          <i class="icon icon-regular-arrow-left ms-0 ms-md-1"></i>
          <span class="d-none d-md-inline-block">{{ t('global.back') }}</span>
        </nuxt-link>
      </div>
    </div>

    <!-- کارت لیست استوری‌ها -->
    <div class="card border-0 shadow-sm">
      <div class="card-body p-0">
        <div class="table-responsive">
          <table class="table table-hover mb-0">
            <thead>
              <tr>
                <th class="border-top-0 ps-4">#</th>
                <th>{{ t('advertise_story.table.image') }}</th>
                <th>{{ t('advertise_story.table.text') }}</th>
                <th>{{ t('advertise_story.table.position') }}</th>
                <th class="text-end">{{ t('advertise_story.table.actions') }}</th>
              </tr>
            </thead>
            <tbody>
              <tr v-for="(story, index) in data.stories" :key="index">
                <td class="ps-4">{{ index + 1 }}</td>
                <td>
                  <img
                    :src="story.image"
                    class="rounded"
                    width="80"
                    height="60"
                    alt="Story image"
                    style="object-fit: cover"
                  />
                </td>
                <td>
                  <p class="mb-0 fw-bold">{{ story.text }}</p>
                </td>
                <td>
                  <span class="badge bg-light text-dark">
                    {{ story.position }}
                  </span>
                </td>
                <td class="text-end pe-4">
                  <button class="btn btn-sm" @click="removeItem(story.id)">
                    <i class="icon icon-regular-trash text-danger"></i>
                  </button>
                </td>
              </tr>
            </tbody>
          </table>
        </div>
      </div>
    </div>

    <!-- مودال افزودن استوری -->
    <teleport to="body">
      <div
        v-if="data.showModal"
        class="modal fade show d-block"
        tabindex="-1"
        style="background-color: rgba(0, 0, 0, 0.5)"
      >
        <div class="modal-dialog">
          <div class="modal-content">
            <div class="modal-header">
              <h5 class="modal-title">{{ t('advertise_story.modal.title') }}</h5>
              <button
                type="button"
                class="btn-close"
                @click="data.showModal = false;"
              ></button>
            </div>
            <div class="modal-body">
              <form @submit.prevent="addStory">
                <div class="mb-3">
                  <label class="form-label">{{ t('advertise_story.modal.image_label') }}</label>
                  <input
                    type="file"
                    class="form-control"
                    accept="image/*"
                    @change="previewImage"
                    ref="fileInput"
                    required
                  />
                  <small class="text-muted">{{ t('advertise_story.modal.image_hint') }}</small>

                  <!-- پیش‌نمایش تصویر با طراحی بهبود یافته -->
                  <div
                    class="mt-3 d-flex align-items-center justify-content-center"
                    v-if="data.imagePreview"
                  >
                    <div
                      class="w-300-px h-300-px bg-light rounded-3 border border-default p-2 overflow-hidden position-relative"
                    >
                      <img
                        :src="data.imagePreview"
                        class="w-100 h-100 object-fit-contain"
                        alt="پیش‌نمایش تصویر"
                      />
                      <span
                        type="button"
                        class="position-absolute top-10-px right-20-px"
                        @click="removeImage"
                      >
                        <i
                          class="icon icon-regular-times text-danger font-size-30"
                        ></i>
                      </span>
                    </div>
                    <!-- دکمه حذف با طراحی جدید -->
                  </div>
                </div>

                <div class="mb-3">
                  <label class="form-label">{{ t('advertise_story.modal.text_label') }}</label>
                  <textarea
                    class="form-control"
                    rows="3"
                    :placeholder=" t('advertise_story.modal.text_placeholder')"
                    v-model="data.form.text"
                    required
                  ></textarea>
                </div>

                <div class="mb-3">
                  <label class="form-label">{{ t('advertise_story.modal.position_label') }}</label>
                  <select
                    class="form-select"
                    v-model="data.form.position"
                    required
                  >
                    <option value="">{{ t('form.dropdown.select') }}</option>
                    <option value="top">{{ t('advertise_story.positions.top') }}</option>
                    <option value="bottom">{{ t('advertise_story.positions.bottom') }}</option>
                    <option value="left">{{ t('advertise_story.positions.left') }}</option>
                    <option value="right">{{ t('advertise_story.positions.right') }}</option>
                  </select>
                </div>

                <div class="d-grid gap-2">
                  <button type="submit" class="btn btn-default">
                    {{ t('advertise_story.modal.save_button') }}
                  </button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </teleport>
  </div>
</template>

<script setup>
import { ref, reactive, onMounted } from "vue";
import { useRoute } from "vue-router";
import { useCookie } from "nuxt/app";

const { $api , $sweetalert } = useNuxtApp();
const route = useRoute();
const token = useCookie("token");


const advertiseId = route.params.id;

const data = reactive({
  stories: [],
  showModal: false,
  imagePreview: null,
  form: {
    image: null,
    text: "",
    position: "",
  },
  advertiseTitle: 'نمونه آگهی تستی'
});

const fileInput = ref(null);

const getStories = async () => {
  await $api
    .post(
      "/user/advertise/story",
      { advertise_id: advertiseId },
      {
        headers: {
          Authorization: "Bearer " + token.value,
        },
      }
    )
    .then((value) => {
      if (value.data.status) {
        data.stories = value.data.data.map((item) => ({
          id: item.id,
          image: item.file || "/upload.png",
          text: item.title,
          position: translatePosition(item.position),
        }));
      }
    })
    .catch((err) => {
      console.error("خطا در دریافت استوری‌ها:", err);
    });
};

const translatePosition = (pos) => {
  switch (pos) {
    case "top":
      return "بالا";
    case "bottom":
      return "پایین";
    case "left":
      return "چپ";
    case "right":
      return "راست";
    default:
      return pos;
  }
};

const addStory = async () => {
  const { text, position, image } = data.form;

  if (!text.trim() || !position || !image) {
    $sweetalert.error(t('advertise_story.errors.fill_all'))
    return;
  }

  const formData = new FormData();
  formData.append("title", text);
  formData.append("file", image);
  formData.append("position", position);
  formData.append("advertise_id", advertiseId);

  await $api
    .post("/user/advertise/story/create", formData, {
      headers: {
        Authorization: "Bearer " + token.value,
        "Content-Type": "multipart/form-data",
      },
    })
    .then((value) => {
      if (value.data.status) {
        $sweetalert.success(t('advertise_story.success.added'))
        data.showModal = false;
        data.imagePreview = null;
        data.form = {
          image: null,
          text: "",
          position: "",
        };
        getStories(); 
      } else {
        $sweetalert.error(t('advertise_story.errors.add_failed'))
      }
    })
    .catch((err) => {
      $sweetalert.error(t('advertise_story.errors.general'))
    });
};

const removeItem = async (storyId) => {
  await $sweetalert.confirm(async () => {
    await $api
      .post(
        "/user/advertise/story/delete",
        {
          advertise_id: advertiseId,
          story_id: storyId,
        },
        {
          headers: {
            Authorization: "Bearer " + token.value,
          },
        }
      )
      .then((value) => {
        if (value.data.status) {
          $sweetalert.success(t('advertise_story.success.deleted'))
          getStories(); 
        } else {
          $sweetalert.error(t('advertise_story.errors.delete_failed'))
        }
      })
      .catch((err) => {
        $sweetalert.error(t('advertise_story.errors.general'))
      });
  });
};

// پیش‌نمایش تصویر انتخاب‌شده
const previewImage = (event) => {
  const input = event.target;
  if (input.files && input.files[0]) {
    const reader = new FileReader();
    reader.onload = (e) => {
      data.imagePreview = e.target.valueult;
      data.form.image = input.files[0];
    };
    reader.readAsDataURL(input.files[0]);
  }
};

// حذف تصویر انتخاب‌شده
const removeImage = () => {
  data.imagePreview = null;
  data.form.image = null;
  if (fileInput.value) {
    fileInput.value.value = "";
  }
};

onMounted(() => {
  getStories();
});
</script>


<style scoped>
.table th {
  font-weight: 600;
  color: #6c757d;
  background-color: #f8f9fa;
}

.table td,
.table th {
  vertical-align: middle;
  padding: 1rem;
}
</style>
